@@ -7,6 +7,6 @@ python -m bmtool.debug
 
 """
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     parser = util.get_argparse(use_description)
-    util.verify_parse(parser)
\ No newline at end of file
+    util.verify_parse(parser)
